@@ -4,18 +4,18 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common  2.033 qw(:Status createSelfTiedObject);
+use IO::Compress::Base::Common  2.034 qw(:Status createSelfTiedObject);
 
-use IO::Uncompress::Base  2.033 ;
-use IO::Uncompress::Adapter::LZO  2.033 ;
+use IO::Uncompress::Base  2.034 ;
+use IO::Uncompress::Adapter::LZO  2.034 ;
 use Compress::LZO qw(crc32 adler32);
-use IO::Compress::Lzop::Constants  2.033 ;
+use IO::Compress::Lzop::Constants  2.034 ;
 
 
 require Exporter ;
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $UnLzopError);
 
-$VERSION = '2.033';
+$VERSION = '2.034';
 $UnLzopError = '';
 
 @ISA    = qw( Exporter IO::Uncompress::Base );
@@ -933,7 +933,7 @@ If the C<$z> object is associated with a file or a filehandle, C<fileno>
 will return the underlying file descriptor. Once the C<close> method is
 called C<fileno> will return C<undef>.
 
-If the C<$z> object is is associated with a buffer, this method will return
+If the C<$z> object is associated with a buffer, this method will return
 C<undef>.
 
 =head2 close
